/******************************************************************************
* C Source: Image Section List                                                *
*                                                                             *
* File:                                                                       *
*    imgsnlst.c                                                               *
*                                                                             *
* Description:                                                                *
*    This set of functions performs various manipulations on a linked list    *
*    (see lnkd_lst.c and lnkd_lst.h) of image sections (see imgsn.c and       *
*    imgsn.h), each node for an individual image section. (see imgsnlst.h).   *
*                                                                             *
* Module List:                                                                *
*    Add_Image_Section_to_List                                                *
*       Insert an image section into the top of an image section list.        *
*    Create_Empty_Image_Section_List                                          *
*       Create a new empty image section list.                                *
*    Delete_Image_Section_List                                                *
*       Delete the linked list for an image section list, but not the image   *
*       section data the list points to.                                      *
*    Delete_Image_Section_List_Data                                           *
*       Delete the linked list for an image section list, AND the image       *
*       section data the list points to.                                      *
*                                                                             *
* History:                                                                    *
*    Created    : 17-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
*                                                                             *
* Copyright (c) 1993, 1994, Association of Universities for Research in       *
* Astronomy, Inc.  All Rights Reserved.                                       *
* Produced under National Aeronautics and Space Administration grant          *
* NAG W-2166.                                                                 *
******************************************************************************/
#include "imgsnlst.h"

#include "imgsectn.h"
#include "lnkd_lst.h"

/******************************************************************************
* Module:                                                                     *
*    Add_Image_Section_to_List                                                *
*                                                                             *
* File:                                                                       *
*    imgsnlst.c                                                               *
*                                                                             *
* Description:                                                                *
*    Adds an image section to the top of an image section list.               *
*                                                                             *
* Return Value:                                                               *
*    none                                                                     *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       List                                                                  *
*          IS_LIST, Reference                                                 *
*             The image section list to which we're adding the image section. *
*       Image_Section                                                         *
*          Image_Section, Reference                                           *
*             The image section we're adding to the image section list.       *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 17-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/*****************************************
* Add_Image_Section_to_List declarations *
*****************************************/
void          Add_Image_Section_to_List( List, Image_Section )
IS_LIST       List         ;
IMAGE_SECTION Image_Section;
{
/**************************************************
* Add_Image_Section_to_List begin executable code *
**************************************************/
   Insert_Linked_List_Data( List, Image_Section );

   return;
}
/************************************************
* Add_Image_Section_to_List end executable code *
************************************************/

/******************************************************************************
* Module:                                                                     *
*    Create_Empty_Image_Section_List                                          *
*                                                                             *
* File:                                                                       *
*    imgsnlst.c                                                               *
*                                                                             *
* Description:                                                                *
*    Create a new empty image section list, allocating memory for the header  *
*    the memory.                                                              *
*                                                                             *
* Return Value:                                                               *
*    IS_LIST: The newly created image section.                                *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       none                                                                  *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 17-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/***********************************************
* Create_Empty_Image_Section_List declarations *
***********************************************/
IS_LIST Create_Empty_Image_Section_List()
{
/********************************************************
* Create_Empty_Image_Section_List begin executable code *
********************************************************/
   return ( IS_LIST )Create_Empty_Linked_List();
}
/******************************************************
* Create_Empty_Image_Section_List end executable code *
******************************************************/

/******************************************************************************
* Module:                                                                     *
*    Delete_Image_Section_List                                                *
*                                                                             *
* File:                                                                       *
*    imgsnlst.c                                                               *
*                                                                             *
* Description:                                                                *
*    Free memory allocated for image section list, but not the data it points *
*    to.                                                                      *
*                                                                             *
* Return Value:                                                               *
*    none                                                                     *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       List                                                                  *
*          IS_LIST, Reference                                                 *
*             The image section list we're deleting from memory.              *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 17-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/*****************************************
* Delete_Image_Section_List declarations *
*****************************************/
void    Delete_Image_Section_List( List )
IS_LIST List;
{
/**************************************************
* Delete_Image_Section_List begin executable code *
**************************************************/
   Delete_Linked_List( List );

   return;
}
/************************************************
* Delete_Image_Section_List end executable code *
************************************************/

/******************************************************************************
* Module:                                                                     *
*    Delete_Image_Section_List_Data                                           *
*                                                                             *
* File:                                                                       *
*    imgsnlst.c                                                               *
*                                                                             *
* Description:                                                                *
*    Free memory allocated for image section list, but AND the data it points *
*    to.                                                                      *
*                                                                             *
* Return Value:                                                               *
*    none                                                                     *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       List                                                                  *
*          IS_LIST, Reference                                                 *
*             The image section list we're deleting from memory.              *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 17-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/**********************************************
* Delete_Image_Section_List_Data declarations *
**********************************************/
void    Delete_Image_Section_List_Data( List )
IS_LIST List;
{
/*******************************************************
* Delete_Image_Section_List_Data begin executable code *
*******************************************************/
   Delete_Linked_List_Data( List, Delete_Image_Section );

   return;
}
/*****************************************************
* Delete_Image_Section_List_Data end executable code *
*****************************************************/
